@@ -96,7 +96,7 @@ void mexFunction(int nlhs, mxArray *plhs[],
 			copy_pfsarray_to_mex( &c2Buf, plhs[1] );
 			copy_pfsarray_to_mex( &c3Buf, plhs[2] );
 		} else if( nlhs == 1 ) {
-			mwSize dims[] = { rows, cols, 3 };
+                  mwSize dims[] = { (mwSize)rows, (mwSize)cols, 3 };
 			plhs[0] = mxCreateNumericArray( 3, dims, mxDEFAULT_ARRAY_CLASS, mxREAL );
 
 			copy_pfsarray_to_mex( &c1Buf, &c2Buf, &c3Buf, plhs[0] );
