@@ -26,6 +26,7 @@
  */
 
 #include <config.h>
+#include <cmath>
 
 #include <stdio.h>
 #include <math.h>
@@ -471,7 +472,7 @@ static void mapFrameToImage( pfs::Array2D *R, pfs::Array2D *G, pfs::Array2D *B,
             clamp( pb-1, 0, 255 ) ).rgb();
         }
         if( infNaNTreatment == INFNAN_MARK_AS_RED ) {
-          if( !isfinite( (*R)(index) ) || !isfinite( (*G)(index) ) || !isfinite( (*B)(index) ) )
+          if( !std::isfinite( (*R)(index) ) || !std::isfinite( (*G)(index) ) || !std::isfinite( (*B)(index) ) )
           {   // x is NaN or Inf 
             pixel = QColor( 255, 0, 0 ).rgb();
           }
@@ -488,7 +489,7 @@ static void mapFrameToImage( pfs::Array2D *R, pfs::Array2D *G, pfs::Array2D *B,
         int p = binarySearchPixels( (*R)(index), lutPixFloor, lutSize );        
         pixel = lutPixel[p];
         if( infNaNTreatment == INFNAN_MARK_AS_RED && (p == 0 || p == LUTSIZE+1)) 
-          if( !isfinite( (*R)(index) ) ) {   // x is NaN or Inf 
+          if( !std::isfinite( (*R)(index) ) ) {   // x is NaN or Inf 
             pixel = QColor( 255, 0, 0 ).rgb();
           }
         
